# __init__.py
"""
# Kabirian-based Optinalysis Models

Kabirian-based optinalysis models (*kbomodels*) consist of a collection of mathematical and statistical techniques designed for analyzing datasets within 
the Kabirian-based optinalysis framework, along with other advanced methodologies. The estimation modules integrated within *kbomodels* include:

1a. **kc_isoptinalysis** : Performs Kabirian-based isomorphic optinalysis to calculate the Kabirian coefficient.    
1b. **doc_kc_isoptinalysis** : Prints the documentation of the kc_isoptinalysis module.

2a. **kc_autoptinalysis** : Performs Kabirian-based automorphic optinalysis to calculate the Kabirian coefficient.
2b. **doc_kc_autoptinalysis** : Prints the documentation of the kc_autoptinalysis.

3a. **pSimSymId** : Translates the Kabirian coefficient of similarity, symmetry, or identity (kc) to probability of similarity, symmetry, or Sidentity (SimSymId).
3b. **doc_pSimSymId** : Prints the documentation of the pSimSymId.
        
4a. **pDsimAsymUid** : Translates probability of similarity, symmetry, or identity (pSimSymId) to probability of dissimilarity, asymmetry, or unidentity (pDsimAsymUid).
4b. **doc_pDsimAsymUid** : Prints the documentation of the pDsimAsymUid.
        
5a. **kc_alt1** : Translates probability of similarity, symmetry, or identity (pSimSymId) to an ascending-alternative (A-alternative) Kabirian coefficient of similarity, symmetry, or identity (kc_alt1).
5b. **doc_kc_alt1** : Prints the documentation of the kc_alt1.
        
6a. **kc_alt2** : Translates probability of similarity, symmetry, or identity (pSimSymId) to a descending-alternative (D-alternative) Kabirian coefficient of similarity, symmetry, or identity (kc_alt2).
6b. **doc_kc_alt2** : Prints the documentation of the kc_alt2.
        
7a. **kc_alt** : Translates Kabirian coefficient of similarity, symmetry, or identity (kc) to its inverse alternative Kabirian coefficient of similarity, symmetry, or identity (kc_alt).
7b. **doc_kc_alt** : Prints the documentation of the kc_alt.
        
8a. **isomorphic_optinalysis** : Performs Kabirian-based isomorphic optinalysis.
8b. **doc_isomorphic_optinalysis** : Prints the documentation of the isomorphic_optinalysis.

9a. **automorphic_optinalysis** : Performs Kabirian-based automorphic optinalysis.
9b. **doc_automorphic_optinalysis** : Prints the documentation of the automorphic_optinalysis.

10a. **stat_SymAsymmetry** : Estimates the statistical symmetry and asymmetry of a dataset using a customized, and optimized Kabirian-based automorphic optinalysis.
10b. **doc_stat_SymAsymmetry** : Prints the documentation of the stat_SymAsymmetry.
        
11a. **bioseq_gpa** : Perform pairwise sequence analysis of aligned biological sequences using a customized, and optimized Kabirian-based    isomorphic optinalysis. 
11b. **doc_bioseq_gpa** : Prints the documentation of the bioseq_gpa.
        
12a. **stat_mirroring** : Performs statistical dispersion estimations on a dataset using a parameterized, customized, and optimized Kabirian-based isomorphic optinalysis.
12b. **doc_stat_mirroring** : Prints the documentation of the stat_mirroring.
        
13a. **famispacing** : Estimates family spacing conformity and disconformity using a customized, and optimized Kabirian-based isomorphic optinalysis.
13b. **doc_famispacing** : Prints the documentation of the famispacing.
        
14a. **smb_ordinalysis** : Perform statistical mirroring-based ordinalysis (SM-based Ordinalysis), a methodology for assessing an individual's level of assessments on a defined ordinal scale by applying a customized and optimized statistical mirroring techniques.
14b. **doc_smb_ordinalysis** : Prints the documentation of the smb_ordinalysis.

"""
from .kbomodels import (kc_isoptinalysis, kc_autoptinalysis, pSimSymId, pDsimAsymUid, kc_alt1, 
                        kc_alt2, kc_alt, isomorphic_optinalysis, automorphic_optinalysis, stat_SymAsymmetry,
                        bioseq_gpa, stat_mirroring, famispacing, smb_ordinalysis,
                        
                        modules, doc_kc_isoptinalysis, doc_kc_autoptinalysis, doc_pSimSymId, doc_pDsimAsymUid, doc_kc_alt1, 
                        doc_kc_alt2, doc_kc_alt, doc_isomorphic_optinalysis, doc_automorphic_optinalysis, doc_stat_SymAsymmetry,
                        doc_bioseq_gpa, doc_stat_mirroring, doc_famispacing, doc_smb_ordinalysis)
